Package: tidyclust
Title: A Common API to Clustering
Version: 0.2.3
Authors@R: c(
    person("Emil", "Hvitfeldt", , "emil.hvitfeldt@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0679-1945")),
    person("Kelly", "Bodwin", , "kelly@bodwin.us", role = "aut"),
    person(given = "Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: A common interface to specifying clustering models, in the
    same style as 'parsnip'. Creates unified interface across different
    functions and computational engines.
License: MIT + file LICENSE
URL: https://github.com/tidymodels/tidyclust,
        https://tidyclust.tidymodels.org/
BugReports: https://github.com/tidymodels/tidyclust/issues
Depends: R (>= 3.6)
Imports: cli (>= 3.0.0), dials (>= 1.1.0), dplyr (>= 1.0.9), flexclust
        (>= 1.3-6), foreach, generics (>= 0.1.2), glue (>= 1.6.2),
        hardhat (>= 1.0.0), modelenv (>= 0.1.0), parsnip (>= 1.0.2),
        prettyunits (>= 1.1.0), Rfast (>= 2.0.6), rlang (>= 1.0.6),
        rsample (>= 1.0.0), stats, tibble (>= 3.1.0), tidyr (>= 1.2.0),
        tune (>= 1.0.0), utils, vctrs (>= 0.5.0)
Suggests: cluster, ClusterR, clustMixType (>= 0.3-5), covr, klaR,
        knitr, modeldata (>= 1.0.0), RcppHungarian, recipes (>= 1.0.0),
        rmarkdown, testthat (>= 3.0.0), workflows (>= 1.1.2)
Config/Needs/website: pkgdown, tidymodels, tidyverse, palmerpenguins,
        patchwork, ggforce, tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Author: Emil Hvitfeldt [aut, cre] (<https://orcid.org/0000-0002-0679-1945>),
  Kelly Bodwin [aut],
  Posit Software, PBC [cph, fnd]
Maintainer: Emil Hvitfeldt <emil.hvitfeldt@posit.co>
Built: R 4.4.1; ; 2024-07-04 13:23:10 UTC; unix
