# Generated by roxygen2: do not edit by hand

S3method(as_tibble,cluster_metric_set)
S3method(augment,cluster_fit)
S3method(check_args,default)
S3method(check_args,hier_clust)
S3method(check_args,k_means)
S3method(extract_cluster_assignment,KMeansCluster)
S3method(extract_cluster_assignment,cluster_fit)
S3method(extract_cluster_assignment,cluster_spec)
S3method(extract_cluster_assignment,hclust)
S3method(extract_cluster_assignment,kmeans)
S3method(extract_cluster_assignment,kmodes)
S3method(extract_cluster_assignment,kproto)
S3method(extract_cluster_assignment,workflow)
S3method(extract_fit_engine,cluster_fit)
S3method(extract_fit_summary,KMeansCluster)
S3method(extract_fit_summary,cluster_fit)
S3method(extract_fit_summary,cluster_spec)
S3method(extract_fit_summary,hclust)
S3method(extract_fit_summary,kmeans)
S3method(extract_fit_summary,kmodes)
S3method(extract_fit_summary,kproto)
S3method(extract_fit_summary,workflow)
S3method(extract_parameter_set_dials,cluster_spec)
S3method(fit,cluster_spec)
S3method(fit_xy,cluster_spec)
S3method(glance,cluster_fit)
S3method(load_pkgs,cluster_spec)
S3method(merge,cluster_spec)
S3method(min_grid,cluster_spec)
S3method(predict,cluster_fit)
S3method(predict,cluster_spec)
S3method(predict_cluster,cluster_fit)
S3method(predict_raw,cluster_fit)
S3method(print,cluster_fit)
S3method(print,cluster_metric_set)
S3method(print,cluster_spec)
S3method(print,control_cluster)
S3method(print,hier_clust)
S3method(print,k_means)
S3method(required_pkgs,cluster_fit)
S3method(required_pkgs,cluster_spec)
S3method(set_args,cluster_spec)
S3method(set_engine,cluster_spec)
S3method(set_mode,cluster_spec)
S3method(silhouette_avg,cluster_fit)
S3method(silhouette_avg,cluster_spec)
S3method(silhouette_avg,workflow)
S3method(sse_ratio,cluster_fit)
S3method(sse_ratio,cluster_spec)
S3method(sse_ratio,workflow)
S3method(sse_total,cluster_fit)
S3method(sse_total,cluster_spec)
S3method(sse_total,workflow)
S3method(sse_within_total,cluster_fit)
S3method(sse_within_total,cluster_spec)
S3method(sse_within_total,workflow)
S3method(tidy,cluster_fit)
S3method(translate_tidyclust,default)
S3method(translate_tidyclust,hier_clust)
S3method(translate_tidyclust,k_means)
S3method(tunable,cluster_spec)
S3method(tunable,k_means)
S3method(tune_args,cluster_spec)
S3method(tune_cluster,cluster_spec)
S3method(tune_cluster,default)
S3method(tune_cluster,workflow)
S3method(update,hier_clust)
S3method(update,k_means)
export("%>%")
export(.hier_clust_fit_stats)
export(.k_means_fit_ClusterR)
export(.k_means_fit_clustMixType)
export(.k_means_fit_klaR)
export(.k_means_fit_stats)
export(augment)
export(cluster_metric_set)
export(control_cluster)
export(cut_height)
export(extract_centroids)
export(extract_cluster_assignment)
export(extract_fit_engine)
export(extract_fit_parsnip)
export(extract_fit_summary)
export(extract_parameter_set_dials)
export(extract_preprocessor)
export(extract_spec_parsnip)
export(finalize_model_tidyclust)
export(finalize_workflow_tidyclust)
export(fit)
export(fit.cluster_spec)
export(fit_xy)
export(fit_xy.cluster_spec)
export(get_tidyclust_colors)
export(glance)
export(hier_clust)
export(k_means)
export(knit_engine_docs)
export(linkage_method)
export(list_md_problems)
export(load_pkgs)
export(make_classes_tidyclust)
export(min_grid)
export(new_cluster_metric)
export(new_cluster_spec)
export(predict.cluster_fit)
export(predict_cluster)
export(predict_cluster.cluster_fit)
export(predict_raw)
export(predict_raw.cluster_fit)
export(reconcile_clusterings_mapping)
export(required_pkgs)
export(set_args)
export(set_engine)
export(set_mode)
export(silhouette)
export(silhouette_avg)
export(silhouette_avg_vec)
export(sse_ratio)
export(sse_ratio_vec)
export(sse_total)
export(sse_total_vec)
export(sse_within)
export(sse_within_total)
export(sse_within_total_vec)
export(tidy)
export(translate_tidyclust)
export(translate_tidyclust.default)
export(tune)
export(tune_cluster)
export(values_linkage_method)
importFrom(dplyr,"%>%")
importFrom(dplyr,bind_cols)
importFrom(generics,augment)
importFrom(generics,fit)
importFrom(generics,fit_xy)
importFrom(generics,glance)
importFrom(generics,min_grid)
importFrom(generics,required_pkgs)
importFrom(generics,tidy)
importFrom(generics,tunable)
importFrom(generics,tune_args)
importFrom(hardhat,extract_fit_engine)
importFrom(hardhat,extract_fit_parsnip)
importFrom(hardhat,extract_parameter_set_dials)
importFrom(hardhat,extract_preprocessor)
importFrom(hardhat,extract_spec_parsnip)
importFrom(hardhat,tune)
importFrom(parsnip,make_call)
importFrom(parsnip,maybe_data_frame)
importFrom(parsnip,maybe_matrix)
importFrom(parsnip,model_printer)
importFrom(parsnip,null_value)
importFrom(parsnip,predict_raw)
importFrom(parsnip,set_args)
importFrom(parsnip,set_engine)
importFrom(parsnip,set_mode)
importFrom(parsnip,show_call)
importFrom(rlang,"%||%")
importFrom(rlang,as_function)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,get_expr)
importFrom(rlang,global_env)
importFrom(rlang,is_logical)
importFrom(rlang,is_true)
importFrom(rlang,missing_arg)
importFrom(rlang,quos)
importFrom(rlang,set_names)
importFrom(rlang,sym)
importFrom(stats,.getXlevels)
importFrom(stats,as.formula)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.weights)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(tibble,as_tibble)
importFrom(tune,load_pkgs)
importFrom(utils,capture.output)
