# silhouette() errors for cluster spec

    Code
      silhouette(spec)
    Condition
      Error in `silhouette()`:
      ! This function requires a fitted model. Please use `fit()` on your cluster specification.

# silhouette_avg() errors for cluster spec

    Code
      silhouette_avg(spec)
    Condition
      Error in `silhouette_avg()`:
      ! This function requires a fitted model. Please use `fit()` on your cluster specification.

