# extract_fit_summary() errors for cluster spec

    Code
      extract_fit_summary(spec)
    Condition
      Error in `extract_fit_summary()`:
      ! This function requires a fitted model. Please use `fit()` on your cluster specification.

