# integrates with workflows::add_variables()

    Code
      fit(wf_spec, data = mtcars)
    Condition
      Error in `x_x()`:
      ! Outcomes are not used in `cluster_spec` objects.

# integrates with workflows::add_formula()

    Code
      fit(wf_spec, data = mtcars)
    Condition
      Error in `x_x()`:
      ! Outcomes are not used in `cluster_spec` objects.

# integrates with workflows::add_recipe()

    Code
      fit(wf_spec, data = mtcars)
    Condition
      Error in `x_x()`:
      ! Outcomes are not used in `cluster_spec` objects.

