# sse_within() errors for cluster spec

    Code
      sse_sse_within(spec)
    Condition
      Error in `sse_sse_within()`:
      ! could not find function "sse_sse_within"

# sse_within_total() errors for cluster spec

    Code
      sse_sse_within_total(spec)
    Condition
      Error in `sse_sse_within_total()`:
      ! could not find function "sse_sse_within_total"

# sse_total() errors for cluster spec

    Code
      sse_sse_within_total(spec)
    Condition
      Error in `sse_sse_within_total()`:
      ! could not find function "sse_sse_within_total"

# sse_ratio() errors for cluster spec

    Code
      sse_ratio(spec)
    Condition
      Error in `sse_ratio()`:
      ! This function requires a fitted model. Please use `fit()` on your cluster specification.

