# set_engine() errors with no engine set

    Code
      set_engine(k_means())
    Condition
      Error in `set_engine()`:
      ! Missing engine. Possible mode/engine combinations are: partition {stats, ClusterR, clustMixType, klaR}

